@@ -5,7 +5,7 @@
 #include <map>
 #include <set>
 
-#include "ldastoolsal/AtExit.hh"
+#include "ldastoolsal/MemChecker.hh"
 #include "ldastoolsal/gpstime.hh"
 #include "ldastoolsal/mutexlock.hh"
 #include "ldastoolsal/Task.hh"
@@ -17,7 +17,7 @@
 #include "diskcacheAPI/Cache/DirectoryManager.hh"
 #include "diskcacheAPI/Cache/HotDirectory.hh"
 
-using LDASTools::AL::AtExit;
+using LDASTools::AL::MemChecker;
 using LDASTools::AL::MutexLock;
 using LDASTools::AL::Task;
 using LDASTools::AL::TaskThread;
@@ -549,7 +549,7 @@ namespace
     wakeup.tv_nsec = 0;
     nanosleep( &wakeup, NULL );
 
-    while( AtExit::IsExiting( ) == false )
+    while( MemChecker::IsExiting( ) == false )
     {
       //-----------------------------------------------------------------
       // Loop over each element in the hot list
