@@ -9,6 +9,7 @@
 
 #include "ldastoolsal/regex.hh"
 #include "ldastoolsal/regexmatch.hh"
+#include "ldastoolsal/Singleton.hh"
 
 #include "genericAPI/Logging.hh"
 
@@ -48,7 +49,30 @@ static const char* sdgt_ext_suffix
 ///     so the regular expression may be modified if the list of
 ///     file extensions is modified.
 //-----------------------------------------------------------------------
-static Regex SDGTx_RegEx( SDGT_PATTERN_DEFAULT, REG_EXTENDED );
+class SDGTx_RegEx
+  : public LDASTools::AL::Singleton< SDGTx_RegEx >,
+    public Regex
+{
+public:
+  SDGTx_RegEx( );
+
+  const Regex& operator=( const Regex& Expression );
+};
+
+SINGLETON_INSTANCE_DEFINITION( LDASTools::AL::SingletonHolder< SDGTx_RegEx > )
+
+SDGTx_RegEx::
+SDGTx_RegEx( )
+: Regex( SDGT_PATTERN_DEFAULT, REG_EXTENDED )
+{
+}
+
+const Regex& SDGTx_RegEx::
+operator=( const Regex& Expression )
+{
+  Regex::operator=( Expression );
+  return *this;
+}
 
 enum {
   SDGTx_S_OFFSET = 1,
@@ -1485,7 +1509,7 @@ namespace diskCache
 	//---------------------------------------------------------------
 	// Refactor the regular expression
 	//---------------------------------------------------------------
-	SDGTx_RegEx = Regex( pattern, REG_EXTENDED );
+	SDGTx_RegEx::Instance( ) = Regex( pattern, REG_EXTENDED );
 	retval = true;
       }
       return retval;
@@ -1540,7 +1564,7 @@ namespace diskCache
       //-----------------------------------------------------------------
       // Refactor the regular expression
       //-----------------------------------------------------------------
-      SDGTx_RegEx = Regex( pattern, REG_EXTENDED );
+      SDGTx_RegEx::Instance( ) = Regex( pattern, REG_EXTENDED );
     }
 
     //-------------------------------------------------------------------
@@ -1591,7 +1615,7 @@ namespace diskCache
 
       try
       {
-	retval = match.match( SDGTx_RegEx, Data.s_filename.c_str( ) );
+	retval = match.match( SDGTx_RegEx::Instance( ), Data.s_filename.c_str( ) );
       }
       catch( ... )
       {
