@@ -10,7 +10,7 @@
 #include <stdexcept>
 #include <typeinfo>
 
-#include "ldastoolsal/AtExit.hh"
+#include "ldastoolsal/MemChecker.hh"
 #include "ldastoolsal/DeadLockDetector.hh"
 #include "ldastoolsal/fstream.hh"
 #include "ldastoolsal/ldasexception.hh"
@@ -29,7 +29,7 @@
 #include "diskcacheAPI.hh"
 #include "Commands.hh"
 
-using LDASTools::AL::AtExit;
+using LDASTools::AL::MemChecker;
 using LDASTools::AL::Thread;
 
 typedef LDASTools::AL::CommandLineOptions 	CommandLineOptions;
@@ -45,6 +45,7 @@ using diskCache::MetaCommand::Filenames;
 using diskCache::MetaCommand::FilenamesRDS;
 using diskCache::MetaCommand::Intervals;
 using diskCache::MetaCommand::MountPointStats;
+using diskCache::MetaCommand::Quit;
 using diskCache::MetaCommand::Scan;
 
 //=======================================================================
@@ -77,6 +78,8 @@ main( int ArgC, char** ArgV )
   //---------------------------------------------------------------------
   // Make sure everything is ready for use
   //---------------------------------------------------------------------
+  MemChecker::Trigger	gc_trigger( true );
+
   Initialize( );
   Thread::StackSizeDefault( 64 * 1024 );
   {
@@ -280,7 +283,6 @@ main( int ArgC, char** ArgV )
 	{
 	  Usage( options.ProgramName( ), common_options );
 	}
-	AtExit::Cleanup( );
 	exit( 0 );
       }
       //-----------------------------------------------------------------
@@ -334,13 +336,26 @@ main( int ArgC, char** ArgV )
 
       switch( CommandTable::Lookup( cmd ) )
       {
+      case CommandTable::CMD_QUIT:
+	{
+	  //-------------------------------------------------------------
+	  // Quit the daemon
+	  //-------------------------------------------------------------
+	  Quit	cmd( options, Server );
+
+	  cmd( );
+	}
+	break;
       case CommandTable::CMD_DAEMON:
 	{
 	  //-------------------------------------------------------------
-	  // Dump the current contents of the cache
+	  // Run as daemon
 	  //-------------------------------------------------------------
-	  Daemon	cmd( options, Server );
+	  std::string	cfg_filename( SYSCONFDIR );
+	  cfg_filename += "/ldas-tools.d/diskcache.cfg";
+	  Daemon	cmd( options, Server, cfg_filename );
 
+	  cmd.ResetOnSignal( true );
 	  cmd( );
 	}
 	break;
@@ -512,7 +527,6 @@ main( int ArgC, char** ArgV )
 #if DEAD_LOCK_DETECTOR_ENABLED
     LDASTools::AL::DeadLockDetector::Dump( );
 #endif /* DEAD_LOCK_DETECTOR_ENABLED */
-    AtExit::Cleanup( );
     exit( 1 );
   }
   catch( ... )
@@ -521,13 +535,11 @@ main( int ArgC, char** ArgV )
 	      << "unknown exception"
 	      << std::endl
       ;
-    AtExit::Cleanup( );
     exit( 1 );
   }
   //---------------------------------------------------------------------
   // Everything went as expected
   //---------------------------------------------------------------------
-  AtExit::Cleanup( );
   return 0;
 }
 
