@@ -11,7 +11,7 @@
 #include "diskcache.hh"
 #include "diskcachecmd.hh"
 
-#include "ldastoolsal/AtExit.hh"
+#include "ldastoolsal/MemChecker.hh"
 #include "ldastoolsal/ConditionalVariable.hh"
 #include "ldastoolsal/fstream.hh"
 #include "ldastoolsal/ldasexception.hh"
@@ -49,7 +49,7 @@ using std::ostringstream;
 using std::runtime_error;
 using std::string;
 
-using LDASTools::AL::AtExit;
+using LDASTools::AL::MemChecker;
 using LDASTools::AL::MutexLock;
 using LDASTools::AL::TaskThread;
 using LDASTools::AL::ThreadPool;
@@ -629,7 +629,7 @@ ScanMountPointList( MountPointScanner::ScanResults& Answer )
       << " scanned in " << ms << " ms "
       << "(" << ms_format( dt ) << ")."
       ;
-   if ( AtExit::IsExiting( ) == false )
+   if ( MemChecker::IsExiting( ) == false )
    {
       GenericAPI::queueLogEntry( msg.str( ),
                                  GenericAPI::LogEntryGroup_type::MT_NOTE,
@@ -641,8 +641,8 @@ ScanMountPointList( MountPointScanner::ScanResults& Answer )
 
 //-----------------------------------------------------------------------
 /// Create an image of the cache file on the storage media.
-//-----------------------------------------------------------------------
-void
+//----------------------------------------------------------------------
+DumpCacheDaemon::thread_type*
 DumpCacheDaemonStart( std::ostream* Stream )
 {
    using namespace diskCache;
@@ -665,6 +665,7 @@ DumpCacheDaemonStart( std::ostream* Stream )
    // Add the task to the thread and get things running
    //--------------------------------------------------------------------
    thread->AddTask( task );
+   return thread;
 }
 
 //-----------------------------------------------------------------------
