@@ -3,21 +3,9 @@
 // This program tests the diskcache standalone command
 //-----------------------------------------------------------------------
 
-#define VALGRIND_DEBUG 0
+#include <cstring>
 
-static const char* VALGRIND =
-#if VALGRIND_DEBUG
- "/usr/bin/valgrind"
-  " --verbose"
-  " --demangle=yes"
-  " --track-origins=yes"
-  " --num-callers=40"
-  " --trace-children=yes"
-  " "
-#else
-  ""
-#endif /* VALGRIND_DEBUG */
-;
+#include "valgrind/valgrind.h"
 
 extern "C" {
 #include <sys/stat.h>
@@ -69,6 +57,28 @@ using diskCache::Cache::SDGTx;
 LDASTools::Testing::UnitTest	Test;
 std::string			ABS_BUILDDIR( "." );
 
+const char*
+valgrind( )
+{
+  static const char* VALGRIND =
+    PROGRAM_VALGRIND
+    " --verbose"
+    " --demangle=yes"
+    " --track-origins=yes"
+    " --num-callers=40"
+    " --trace-children=yes"
+    " --log-file=test_diskcache.valgrind.log"
+    " "
+    ;
+
+  if ( RUNNING_ON_VALGRIND
+       && ( strlen( PROGRAM_VALGRIND ) > 0 ) )
+  {
+    return VALGRIND;
+  }
+  return "";
+}
+
 //-----------------------------------------------------------------------
 // Main testing
 //-----------------------------------------------------------------------
@@ -189,7 +199,8 @@ test_2942_multiple_extensions( )
     binary_filename << TEST_NAME << ".cache";
     std::ostringstream	cmd;
 
-    cmd << VALGRIND << ABS_BUILDDIR << "/diskcache"
+    cmd << valgrind( )
+	<< ABS_BUILDDIR << "/diskcache"
 	<< " --log-directory -"
 	<< " scan"
 	<< " --mount-points " << cwd << "/" << TEST_DIR_ROOT
@@ -367,7 +378,8 @@ test_2942_multiple_extensions_single_out( )
     binary_filename << TEST_NAME << ".cache";
     std::ostringstream	cmd;
 
-    cmd << VALGRIND << ABS_BUILDDIR << "/diskcache"
+    cmd << valgrind( )
+	<< ABS_BUILDDIR << "/diskcache"
 	<< " --log-directory -"
 	<< " scan"
 	<< " --mount-points " << cwd << "/" << TEST_DIR_ROOT
@@ -542,7 +554,8 @@ test_2942_multiple_extensions_single_out_non_gwf( )
     binary_filename << TEST_NAME << ".cache";
     std::ostringstream	cmd;
 
-    cmd << VALGRIND << ABS_BUILDDIR << "/diskcache"
+    cmd << valgrind( )
+	<< ABS_BUILDDIR << "/diskcache"
 	<< " --log-directory -"
 	<< " scan"
 	<< " --mount-points " << cwd << "/" << TEST_DIR_ROOT
