@@ -1172,11 +1172,11 @@ crc_file_checksum_only( IStream& Stream, fr_header_type Header )
       {
 	recorded_crc_type = ChecksumScheme( );
       }
-      CheckSum*
+      std::unique_ptr< CheckSum >
 	recorded_checksum( CheckSum::Create( (CheckSum::kind_type)
 					     recorded_crc_type,
 					     recorded_crc_value ) );
-      verify_checksum( recorded_checksum,
+      verify_checksum( recorded_checksum.get( ),
 		       crc.get( ),
 		       "FR_END_OF_FILE",
 		       m_must_have_eof_checksum );
