@@ -14,7 +14,7 @@ extern "C" {
 #include <sstream>
 #include <string>
 
-#include "ldastoolsal/AtExit.hh"
+#include "ldastoolsal/MemChecker.hh"
 #include "ldastoolsal/CommandLineOptions.hh"
 #include "ldastoolsal/unordered_map.hh"
 #include "ldastoolsal/fstream.hh"
@@ -26,6 +26,7 @@ extern "C" {
 
 using std::string;
 using LDASTools::AL::filebuf;
+using LDASTools::AL::MemChecker;
 
 using LDASTools::AL::unordered_map;
 typedef LDASTools::AL::CommandLineOptions CommandLineOptions;
@@ -41,7 +42,6 @@ using FrameCPP::FrVect;
 inline void
 depart( int Status )
 {
-  LDASTools::AL::AtExit::Cleanup( );
   exit( Status );
 }
 
@@ -269,7 +269,8 @@ int
 main( int ArgC, char**ArgV )
 try
 {
-  CommandLine	cl( ArgC, ArgV );
+  MemChecker::Trigger	gc_trigger( true );
+  CommandLine		cl( ArgC, ArgV );
 
   if ( ( cl.size( ) != 1 )
        || ( cl.BadOption( ) ) )
