@@ -25,7 +25,7 @@
 #include <string>
 #include <vector>
 
-#include "ldastoolsal/AtExit.hh"
+#include "ldastoolsal/MemChecker.hh"
 #include "ldastoolsal/autoarray.hh"
 #include "ldastoolsal/CommandLineOptions.hh"
 #include "ldastoolsal/fstream.hh"
@@ -38,7 +38,7 @@
 #include "framecpp/Common/Verify.hh"
 #include "framecpp/FrameCPP.hh"
 
-using LDASTools::AL::AtExit;
+using LDASTools::AL::MemChecker;
 using LDASTools::AL::AutoArray;
 using LDASTools::AL::unordered_map;
 
@@ -85,7 +85,6 @@ class CommandLine;
 inline void
 depart( int ExitCode )
 {
-  AtExit::Cleanup( );
   exit( ExitCode );
 }
 
@@ -889,6 +888,7 @@ int
 main( int ArgC, const char**ArgV )
 try
 {
+  MemChecker::Trigger	gc_trigger( true );
   CommandLine		cl( ArgC, ArgV );
   AutoArray< CHAR >	buffer( new CHAR[ cl.BlockSize( ) ] );
   int			exit_status( 0 );
