@@ -13,7 +13,7 @@
 #include <stdexcept>
 #include <string>
 
-#include "ldastoolsal/AtExit.hh"
+#include "ldastoolsal/MemChecker.hh"
 #include "ldastoolsal/CommandLineOptions.hh"
 #include "ldastoolsal/fstream.hh"
 #include "ldastoolsal/util.hh"
@@ -24,7 +24,7 @@
 
 using std::filebuf;
 
-using LDASTools::AL::AtExit;
+using LDASTools::AL::MemChecker;
 using LDASTools::AL::cmp_nocase;
 
 using FrameCPP::Common::FrameBuffer;
@@ -94,7 +94,6 @@ object_type convert_to_type( const std::string& Type );
 inline void
 depart( int ExitCode )
 {
-  AtExit::Cleanup( );
   exit( ExitCode );
 }
 
@@ -526,9 +525,10 @@ int
 main( int ArgC, char**ArgV )
 try
 {
-  CommandLine	cl( ArgC, ArgV );
+  MemChecker::Trigger	gc_trigger( true );
+  CommandLine		cl( ArgC, ArgV );
 
-  int		exit_status = 0;
+  int			exit_status = 0;
 
   FrameCPP::Initialize( );
 
