@@ -9,7 +9,7 @@
 #include <memory>
 #include <stdexcept>
 
-#include "ldastoolsal/AtExit.hh"
+#include "ldastoolsal/MemChecker.hh"
 #include "ldastoolsal/CommandLineOptions.hh"
 
 #include "framecpp/Common/FrameSpec.hh"
@@ -19,7 +19,7 @@
 
 #define DEFAULT_BUFFER_SIZE 256
 
-using LDASTools::AL::AtExit;
+using LDASTools::AL::MemChecker;
 
 typedef LDASTools::AL::CommandLineOptions CommandLineOptions;
 typedef CommandLineOptions::Option Option;
@@ -50,7 +50,6 @@ namespace
 inline void
 depart( int ExitCode )
 {
-  AtExit::Cleanup( );
   exit( ExitCode );
 }
 
@@ -534,7 +533,8 @@ int
 main( int ArgC, char**ArgV )
 try
 {
-  CommandLine	cl( ArgC, ArgV );
+  MemChecker::Trigger	gc_trigger( true );
+  CommandLine		cl( ArgC, ArgV );
 
   Verify	verifier;
   INT_4U	exit_status = VerifyException::NO_ERROR;
