@@ -14,7 +14,7 @@
 #include <stdexcept>
 
 // General
-#include "ldastoolsal/AtExit.hh"
+#include "ldastoolsal/MemChecker.hh"
 #include "ldastoolsal/autoarray.hh"
 #include "ldastoolsal/gpstime.hh"
 #include "ldastoolsal/regex.hh"
@@ -52,7 +52,7 @@
 using namespace std;
 using namespace FrameCPP;
 
-using LDASTools::AL::AtExit;
+using LDASTools::AL::MemChecker;
 using LDASTools::AL::AutoArray;
 using LDASTools::AL::GPSTime;   
 
@@ -910,7 +910,7 @@ ProcessRequest( stream_type Output )
 	       current != end;
 	       ++current )
 	 {
-	    if ( AtExit::IsExiting( ) )
+	    if ( MemChecker::IsExiting( ) )
 	    {
 	       std::ostringstream 	msg;
 	       
