@@ -15,7 +15,7 @@ namespace anonymous
   void exit_handler( );
 }
 
-SINGLETON_INSTANCE_DEFINITION(SingletonHolder<AtExit>)
+// SINGLETON_INSTANCE_DEFINITION(SingletonHolder<AtExit>)
 
 namespace
 {
@@ -289,7 +289,9 @@ namespace
   {
     exit_queue( ).IsExiting( true );
 
+#if 0
     AtExit::Cleanup( );
+#endif /* 0 */
   }
 #endif /* 0 */
 
