@@ -1,9 +1,9 @@
 #include <cctype>
+#include <cstdlib>
 #include <cstring>
 
 #include <string>
 
-#include "ldastoolsal/AtExit.hh"
 #include "ldastoolsal/CommandLineOptions.hh"
 #include "ldastoolsal/regex.hh"
 #include "ldastoolsal/regexmatch.hh"
@@ -564,7 +564,6 @@ namespace LDASTools
 	    doxygen_option_set	dos( m_program_name, Options );
 
 	    dos.Write( std::cout );
-	    LDASTools::AL::AtExit::Cleanup( );
 	    exit( 0 );
 	  }
 	  //---------------------------------------------------------------
