@@ -9,12 +9,12 @@
 #include <algorithm>
 #include <fstream>
 
-#include "ldastoolsal/AtExit.hh"
+#include "ldastoolsal/MemChecker.hh"
 #include "ldastoolsal/fstream.hh"
 #include "ldastoolsal/Log.hh"
 #include "ldastoolsal/System.hh"
 
-using LDASTools::AL::AtExit;
+using LDASTools::AL::MemChecker;
 using LDASTools::System::ErrnoMessage;
 
 static const int OFFLOAD_CPU_FOR_N_SECONDS = 1;
@@ -192,6 +192,10 @@ namespace LDASTools
     //-------------------------------------------------------------------
     Log::StreamFile::
     StreamFile( )
+      : rotate_bytes( 0 ),
+	rotate_bytes_trigger( 0 ),
+	rotate_entries( 0 ),
+	rotate_entries_trigger( 0 )
     {
     }
 
@@ -243,7 +247,7 @@ namespace LDASTools
 	       << filename_pattern
 	       << filename_extension
 	;
-      open( filename.str( ) );
+      open( filename.str( ).c_str( ) );
       onOpen( );
     }
 
@@ -487,7 +491,8 @@ namespace LDASTools
       // Start the thread which is responsible for streaming the messages
       // to the output stream.
       //-----------------------------------------------------------------
-      LDASTools::AL::SharedPtr< LogCB >	cb( new LogCB( this ) );
+      LDASTools::AL::SharedPtr< Log::StreamCBInterface >
+	cb( new LogCB( this ) );
 
       m_stream.reset( new StreamStdErr( ) );
       m_stream->Callback( cb );
@@ -669,7 +674,7 @@ namespace LDASTools
 	//---------------------------------------------------------------
 	// main thread execution
 	//---------------------------------------------------------------
-	while ( AtExit::IsExiting( ) == false )
+	while ( MemChecker::IsExiting( ) == false )
 	{
 	  try
 	  {
