@@ -12,7 +12,7 @@
 #include <sstream>
 #include <stdexcept>
 
-#include "ldastoolsal/AtExit.hh"
+#include "ldastoolsal/MemChecker.hh"
 #include "ldastoolsal/IOLock.hh"
 #include "ldastoolsal/unordered_map.hh"
 #include "ldastoolsal/ldasexception.hh"
@@ -27,7 +27,7 @@
 #endif /* ALT_PTHREAD_STACK_MIN */
 
 using LDASTools::AL::Thread;
-using LDASTools::AL::AtExit;
+using LDASTools::AL::MemChecker;
 using LDASTools::AL::MutexLock;
 using LDASTools::AL::unordered_map;
 
@@ -758,7 +758,7 @@ namespace LDASTools
     Thread* Thread::
     start_routine( Thread* ThreadSource )
     {
-      if ( AtExit::IsExiting( ) == false )
+      if ( MemChecker::IsExiting( ) == false )
       {
 	try
 	{
