@@ -6,7 +6,6 @@ LDASTools::Testing::UnitTestTS	Test;
 
 static void test_1( );
 
-using LDASTools::AL::AtExit;
 using LDASTools::AL::Singleton;
 
 int
@@ -25,7 +24,6 @@ main( int ArgC, char** ArgV )
   //---------------------------------------------------------------------
   // Exit with the appropriate exit status
   //---------------------------------------------------------------------
-  AtExit::Cleanup( );
   Test.Exit();
   return 1;
 }
