@@ -6,7 +6,7 @@
 #include <sstream>
 #include <vector>
 
-#include "ldastoolsal/AtExit.hh"
+#include "ldastoolsal/MemChecker.hh"
 #include "ldastoolsal/CommandLineOptions.hh"
 #include "ldastoolsal/gpstime.hh"
 #include "ldastoolsal/MkDir.hh"
@@ -43,6 +43,7 @@
  * --md5sumregexp "s,frames,meta/frames,i"
  */
 
+using LDASTools::AL::MemChecker;
 using LDASTools::Cmd::MkDir;
 using LDASTools::Cmd::Sed;
 
@@ -70,7 +71,6 @@ typedef diskCache::ServerInterface ServerInterface;
 static inline void
 depart( int ExitCode )
 {
-  LDASTools::AL::AtExit::Cleanup( );
   exit( ExitCode );
 }
 
@@ -162,7 +162,8 @@ private:
 int
 main( int ArgC, char** ArgV )
 {
-  static const char* caller = "main";
+  static const char*	caller = "main";
+  MemChecker::Trigger	gc_trigger( true );
 
   FrameCPP::Initialize( );
 
@@ -379,7 +380,6 @@ main( int ArgC, char** ArgV )
 		       "CMD_CREATE_RDS" );
   }
 
-  LDASTools::AL::AtExit::Cleanup( );
   return 0;
 }
 
@@ -1028,7 +1028,7 @@ query( const std::string Query )
 			 30,
 			 caller,
 			 "CMD_CREATE_RDS" );
-      std::ifstream	s( m.getSubString( 1 ) );
+      std::ifstream	s( m.getSubString( 1 ).c_str( ) );
 
       if ( s.is_open( ) )
       {
