@@ -5,7 +5,7 @@
 #include <map>
 #include <set>
 
-#include "ldastoolsal/AtExit.hh"
+#include "ldastoolsal/MemChecker.hh"
 #include "ldastoolsal/CommandLineOptions.hh"
 #include "ldastoolsal/fstream.hh"
 #include "ldastoolsal/gpstime.hh"
@@ -38,6 +38,8 @@ static const int TREND_DATA_SUBTYPE = 1; /* Maybe better as mask of stats */
 //-----------------------------------------------------------------------
 //-----------------------------------------------------------------------
 
+using LDASTools::AL::MemChecker;
+
 using FrameCPP::Common::FrameBuffer;
 
 typedef FrameBuffer< LDASTools::AL::filebuf > frame_buffer_type;
@@ -57,7 +59,6 @@ static void store_trend_channels_as_frproc( CommandLine& Options );
 static inline void
 depart( int ExitCode )
 {
-  LDASTools::AL::AtExit::Cleanup( );
   exit( ExitCode );
 }
 
@@ -262,7 +263,8 @@ operator()( const std::string& ChannelName )
 int
 main( int ArgC, char** ArgV )
 {
-  static const char* caller = "main";
+  static const char*	caller = "main";
+  MemChecker::Trigger	gc_trigger( true );
 
   FrameCPP::Initialize( );
 
@@ -315,7 +317,6 @@ main( int ArgC, char** ArgV )
 		       "CMD_CREATE_RDS" );
   }
 
-  LDASTools::AL::AtExit::Cleanup( );
   return 0;
 }
 
